@@ -3,6 +3,7 @@ import json
 
 from django.http import HttpResponse, HttpResponseBadRequest
 from django.views.decorators.csrf import csrf_exempt
+from django.core.mail import mail_admins
 
 from .models import Blacklist
 
@@ -19,10 +20,22 @@ def sns_notification(request):
     except ValueError:
         return HttpResponseBadRequest('Invalid JSON')
 
+    # handle SNS subscription
+    if data['Type'] == 'SubscriptionConfirmation':
+        subscribe_url = data['SubscribeURL']
+        subscribe_body = """
+        Please visit this URL below to confirm your subscription with SNS
+
+        %s """ % subscribe_url
+
+        mail_admins('Please confirm SNS subscription', subscribe_body)
+        return HttpResponse('OK')
+
+    #
     try:
         message = json.loads(data['Message'])
     except ValueError:
-        assert False, request.raw_post_data
+        assert False, data['Message']
 
     #
     type = 0 if message['notificationType'] == 'Bounce' else 1
